#!/bin/bash -

# This script is used when we build libguestfs from brew, as sometimes
# we require packages which are not available in the current version
# of RHEL.  Normally these updated packages would be released along
# with libguestfs in the next RHEL, although unfortunately sometimes
# that doesn't happen (eg. RHBZ#1199605).

set -x

# The kernel package doesn't install unless xfsprogs >= 4.3.0
# is installed.
xfsprogs="$(brew -q latest-pkg rhel-7.3-candidate xfsprogs |
            awk '{print $1}')"

# linux-firmware is for virt-p2v, see RHBZ#1364419
linux_firmware="$(brew -q latest-pkg rhel-7.3-candidate linux-firmware |
                  awk '{print $1}')"

# libsemanage.so.1 is needed by new selinux-policy package in 7.3.
pkgs="
  copy-jdk-configs-1.1-5.el7
  $linux_firmware
  mozjs17-17.0.0-19.el7
  ocaml-4.01.0-22.7.el7
  polkit-0.112-9.el7
  systemd-219-24.el7
  supermin-5.1.16-4.el7
  $xfsprogs
"

for pkg in $pkgs ; do
    brew tag-pkg rhel-7.3-temp-override $pkg
done

for pkg in $pkgs ; do
    brew wait-repo rhel-7.3-build --build=$pkg
done
